@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.50';
+our $VERSION = '0.51';
 
 use Code::TidyAll::Config::INI::Reader 0.44;
 use List::Util 1.45 qw( uniqstr );
@@ -145,12 +145,10 @@ sub _new_tidyall_ini {
         'PerlTidy' => {
             select => [$perl_select],
             ignore => [ $self->_default_perl_ignore ],
-            argv   => '--profile=$ROOT/perltidyrc',
         },
         'PerlCritic' => {
             select => [$perl_select],
             ignore => [ $self->_default_perl_ignore ],
-            argv   => '--profile=$ROOT/perltidyrc',
         },
     );
 
@@ -208,6 +206,15 @@ sub _config_to_ini {
         }
     }
 
+    for my $section ( keys %{$tidyall} ) {
+        if ( $section =~ /PerlTidy/ ) {
+            $tidyall->{$section}{argv} = '--profile=$ROOT/perltidyrc';
+        }
+        elsif ( $section =~ /PerlCritic/ ) {
+            $tidyall->{$section}{argv} = '--profile=$ROOT/perlcriticrc';
+        }
+    }
+
     my $sorter = sbe(
         [ 'select', 'ignore' ],
         {
@@ -268,7 +275,7 @@ Dist::Zilla::Plugin::DROLSKY::TidyAll - Creates default tidyall.ini, perltidyrc,
 
 =head1 VERSION
 
-version 0.50
+version 0.51
 
 =for Pod::Coverage .*
 
